import React, {Component} from 'react'
import PropTypes from 'prop-types'
import { Form, Row, Col, Button, Input, notification } from 'antd'
// import './index.scss'
import asyncComponent from '@/utils/asyncComponent'

const ColorSketch = asyncComponent(() => import('@/mob/colorsketch'))
const MkEditIcon = asyncComponent(() => import('@/components/mkIcon'))

class MenusColumn extends Component {
  static propTpyes = {
    menus: PropTypes.array,
    columnChange: PropTypes.func
  }

  handleConfirm = () => {
    const { menus } = this.props
    // 表单提交时检查输入值是否正确
    this.props.form.validateFieldsAndScroll((err, values) => {
      if (!err) {
        if (menus.filter(item => item.sign === values.sign).length > 0) {
          notification.warning({
            top: 92,
            message: '标识已存在！',
            duration: 2
          })
          return
        }

        this.props.columnChange(values)
        this.props.form.setFieldsValue({
          sign: ''
        })
      }
    })
  }

  render() {
    const { getFieldDecorator } = this.props.form
    const formItemLayout = {
      labelCol: {
        xs: { span: 24 },
        sm: { span: 8 }
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 }
      }
    }

    return (
      <Form {...formItemLayout} className="node-form">
        <Row gutter={24}>
          <Col span={6}>
            <Form.Item label="标识">
              {getFieldDecorator('sign', {
                initialValue: ''
              })(<Input placeholder="" autoComplete="off" />)}
            </Form.Item>
          </Col>
          <Col span={8}>
            <Form.Item label="颜色">
              {getFieldDecorator('color', {
                initialValue: '#e8e8e8',
                rules: [
                  {
                    required: true,
                    message: '请选择颜色!'
                  }
                ]
              })(<ColorSketch />)}
            </Form.Item>
          </Col>
          <Col span={7}>
            <Form.Item label="图标">
              {getFieldDecorator('icon', {
                initialValue: ''
              })(
                <MkEditIcon allowClear/>
              )}
            </Form.Item>
          </Col>
          <Col span={3} className="add">
            <Button onClick={this.handleConfirm} type="primary" className="mk-green">
              添加
            </Button>
          </Col>
        </Row>
      </Form>
    )
  }
}

export default Form.create()(MenusColumn)